import * as react_jsx_runtime from 'react/jsx-runtime';
import * as react from 'react';
import { Dispatch, SetStateAction, ReactNode } from 'react';
import { Chain, WalletArgsFor, Wallet } from '@crossmint/wallets-sdk';
import { HandshakeParent } from '@crossmint/client-sdk-window';
import { signerOutboundEvents, signerInboundEvents } from '@crossmint/client-signers';

type ValidWalletState = {
    status: "not-loaded" | "in-progress";
} | {
    status: "loaded";
    wallet: Wallet<Chain>;
} | {
    status: "error";
    error: string;
};
type WalletContextFunctions = {
    getOrCreateWallet: <C extends Chain>(props: WalletArgsFor<C>) => Promise<{
        startedCreation: boolean;
        reason?: string;
    }>;
    setState: Dispatch<SetStateAction<ValidWalletState>>;
    clearWallet: () => void;
    needsAuth: boolean;
    sendEmailWithOtp: (() => Promise<void>) | null;
    verifyOtp: ((otp: string) => Promise<void>) | null;
    reject: ((error: Error) => void) | null;
};
type LoadedWalletState<C extends Chain> = {
    status: "loaded";
    wallet: Wallet<C>;
    error?: undefined;
};
type WalletContext<C extends Chain = Chain> = ({
    status: "not-loaded" | "in-progress";
    wallet?: undefined;
    error?: undefined;
} & WalletContextFunctions) | ({
    status: "error";
    wallet?: undefined;
    error: string;
} & WalletContextFunctions) | (LoadedWalletState<C> & WalletContextFunctions);
declare const WalletContext: react.Context<WalletContext<Chain>>;
declare function deriveErrorState(error: unknown): {
    status: "error";
    error: string;
};
interface CrossmintWalletProviderProps {
    children: ReactNode;
    getHandshakeParent?: () => HandshakeParent<typeof signerOutboundEvents, typeof signerInboundEvents>;
}
declare function CrossmintWalletProvider({ children, getHandshakeParent }: CrossmintWalletProviderProps): react_jsx_runtime.JSX.Element;

export { CrossmintWalletProvider, type CrossmintWalletProviderProps, type ValidWalletState, WalletContext, deriveErrorState };
